<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Data::SyncthingConnection</name>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="368"/>
        <source>Unable to pause/resume a devices when not connected</source>
        <translation>未连接时无法暂停/恢复设备</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="416"/>
        <source>Unable to request device pause/resume: </source>
        <translation>无法请求设备暂停/恢复： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="483"/>
        <source>Unable to pause/resume a folders when not connected</source>
        <translation>未连接时无法暂停/恢复目录</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="520"/>
        <source>Unable to request folder pause/resume: </source>
        <translation>无法请求目录暂停/恢复： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="551"/>
        <source>Unable to rescan: No folder ID specified.</source>
        <translation>无法重新扫描：未指定目录 ID。</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="581"/>
        <source>Unable to request rescan: </source>
        <translation>无法请求重新扫描： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="612"/>
        <source>Unable to request restart: </source>
        <translation>无法请求重启： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="641"/>
        <source>Unable to request shutdown: </source>
        <translation>无法请求关闭： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="676"/>
        <source>Unable to request clearing errors: </source>
        <translation>无法请求清除错误： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="710"/>
        <source>Unable to parse Syncthing config: </source>
        <translation>无法解析 Syncthing 配置： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="727"/>
        <source>Unable to request Syncthing config: </source>
        <translation>无法请求 Syncthing 配置： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="858"/>
        <source>Unable to parse Syncthing status: </source>
        <translation>无法解析 Syncthing 状态： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="877"/>
        <source>Unable to request Syncthing status: </source>
        <translation>无法请求 Syncthing 状态： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="925"/>
        <source>Unable to parse connections: </source>
        <translation>无法解析连接： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1008"/>
        <source>Unable to request connections: </source>
        <translation>无法请求连接： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1047"/>
        <source>Unable to parse errors: </source>
        <translation>无法解析错误： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1087"/>
        <source>Unable to request errors: </source>
        <translation>无法请求错误： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1119"/>
        <source>Unable to parse folder statistics: </source>
        <translation>无法解析目录统计信息： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1170"/>
        <location filename="../syncthingconnection_requests.cpp" line="1232"/>
        <source>Unable to request folder statistics: </source>
        <translation>无法请求目录统计信息： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1213"/>
        <source>Unable to parse status for folder %1: </source>
        <translation>无法解析目录 %1 的状态： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1280"/>
        <source>Unable to parse pull errors for folder %1: </source>
        <translation>无法解析目录 %1 的拉取错误： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1294"/>
        <source>Unable to request pull errors for folder %1: </source>
        <translation>无法请求目录 %1 的拉取错误： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1360"/>
        <source>Unable to parse completion for device/folder %1/%2: </source>
        <translation>无法解析设备/目录 %1/%2 的完成情况： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1375"/>
        <source>Unable to request completion for device/folder %1/%2: </source>
        <translation>无法请求设备/目录 %1/%2 的完成情况： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1407"/>
        <source>Unable to parse device statistics: </source>
        <translation>无法解析设备统计数据： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1434"/>
        <source>Unable to request device statistics: </source>
        <translation>无法请求设备统计数据： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1462"/>
        <source>Unable to parse version: </source>
        <translation>无法解析版本： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1476"/>
        <source>Unable to request version: </source>
        <translation>无法请求版本： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1511"/>
        <source>Unable to request QR-Code: </source>
        <translation>无法请求二维码： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1544"/>
        <source>Unable to parse Syncthing log: </source>
        <translation>无法解析 Syncthing 日志： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1561"/>
        <source>Unable to request Syncthing log: </source>
        <translation>无法请求 Syncthing 日志： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1594"/>
        <source>Unable to request directory override: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1627"/>
        <source>Unable to request directory revert: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1759"/>
        <source>Unable to parse response for browsing &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1773"/>
        <source>Unable to browse &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1797"/>
        <location filename="../syncthingconnection_requests.cpp" line="1821"/>
        <source>Unable to query ignore patterns of &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1847"/>
        <source>Unable to change ignore patterns of &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1891"/>
        <source>Unable to post config: </source>
        <translation>无法发布日志： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2099"/>
        <source>Unable to parse Syncthing events: </source>
        <translation>无法解析 Syncthing 事件： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2128"/>
        <source>Unable to request Syncthing events: </source>
        <translation>无法请求 Syncthing 事件： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2726"/>
        <source>Unable to parse disk events: </source>
        <translation>无法解析磁盘事件： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2751"/>
        <source>Unable to request disk events: </source>
        <translation>无法请求磁盘事件： </translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="180"/>
        <source>disconnected</source>
        <translation>已断线</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="182"/>
        <source>reconnecting</source>
        <translation>重连中</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="184"/>
        <source>connected</source>
        <translation>已连接</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="186"/>
        <source>connected, scanning</source>
        <translation>已连接，扫描中</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="188"/>
        <source>connected, paused</source>
        <translation>已连接，已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="190"/>
        <source>connected, synchronizing</source>
        <translation>已连接，同步中</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="192"/>
        <source>connected, remote not in sync</source>
        <translation>已连接，远程未同步</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="194"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="465"/>
        <source>Connection configuration is insufficient.</source>
        <translation>缺少连接配置。</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="938"/>
        <source>Unable to parse timestamp &quot;%1&quot; (%2): %3</source>
        <translation>无法解析时间戳 &quot;%1&quot; (%2): %3</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1011"/>
        <source>Unable to locate certificate used by Syncthing.</source>
        <translation>无法找到 Syncthing 使用的证书。</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1017"/>
        <source>Unable to load certificate used by Syncthing.</source>
        <translation>无法加载 Syncthing 使用的证书。</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1218"/>
        <source>at offset %1</source>
        <translation>在偏移量 %1 处</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.h" line="691"/>
        <source>connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.h" line="693"/>
        <source>, re-connect attempt every %1 ms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingNotifier</name>
    <message>
        <location filename="../syncthingnotifier.cpp" line="82"/>
        <source>Device %1 (%2) wants to connect.</source>
        <translation>设备 %1 (%2) 想要连接。</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="96"/>
        <source>Device </source>
        <translation>设备 </translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="96"/>
        <source>Unknown device </source>
        <translation>未知设备 </translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="98"/>
        <source> wants to share folder %1.</source>
        <translation> 想要分享目录 %1。</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="100"/>
        <source> wants to share folder %1 (%2).</source>
        <translation> 想要分享目录  %1 (%2)。</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="115"/>
        <source>Failed to start Syncthing</source>
        <translation>启动 Syncthing 失败</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="116"/>
        <source>Maybe the configured binary path is wrong or the binary is not marked as executable.</source>
        <translation>也许配置的二进制文件路径是错误的，或者二进制文件没有被标记为可执行文件。</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="119"/>
        <source>Syncthing crashed</source>
        <translation>Syncthing 崩溃了</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="122"/>
        <source>Syncthing launcher error occurred</source>
        <translation>Syncthing 启动器发生错误</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingService</name>
    <message>
        <location filename="../syncthingservice.cpp" line="378"/>
        <source>start unit</source>
        <translation>启动单位</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="380"/>
        <source>stop unit</source>
        <translation>停止单位</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="395"/>
        <source>enable unit</source>
        <translation>启用单位</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="397"/>
        <source>disable unit</source>
        <translation>禁用单位</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="407"/>
        <source>reload all unit files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::Utils</name>
    <message>
        <location filename="../utils.cpp" line="37"/>
        <source>%1 ago</source>
        <translation>%1 前</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="40"/>
        <source>right now</source>
        <translation>现在</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="51"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message numerus="yes">
        <location filename="../utils.cpp" line="67"/>
        <source>%1 file(s)</source>
        <translation>
            <numerusform>%1 个文件</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../utils.cpp" line="68"/>
        <source>%1 dir(s)</source>
        <translation>
            <numerusform>%1 个目录</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="83"/>
        <source>Synchronization of local folder %1 complete</source>
        <translation>完成本地目录 %1 的同步</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="86"/>
        <source>Synchronization of %1 on %2 complete</source>
        <translation>完成 %1 在 %2 上的同步</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="91"/>
        <source>Synchronization of the following local folders complete:
</source>
        <translation>完成以下本地目录的同步：
</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="94"/>
        <source>Synchronization of the following folders on %1 complete:
</source>
        <translation>完成以下目录在 %1 上的同步：
</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="105"/>
        <source>file system watcher and periodic rescan disabled</source>
        <translation>禁用文件系统监视和定期重新扫描</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="107"/>
        <source>file system watcher active, periodic rescan disabled</source>
        <translation>文件系统监视已激活，定期重新扫描已禁用</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="110"/>
        <source>, file system watcher enabled</source>
        <translation>，文件系统监视已启用</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="111"/>
        <source>, file system watcher disabled</source>
        <translation>，文件系统监视已禁用</translation>
    </message>
</context>
<context>
    <name>SyncthingDev</name>
    <message>
        <source>paused</source>
        <translation type="vanished">已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="36"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="39"/>
        <source>Syncing (%1 %, %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingDevStatus</name>
    <message>
        <source>unknown</source>
        <translation type="vanished">未知</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation type="vanished">已断线</translation>
    </message>
    <message>
        <source>this device</source>
        <translation type="vanished">本设备</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">空闲</translation>
    </message>
    <message>
        <source>synchronizing</source>
        <translation type="vanished">同步中</translation>
    </message>
    <message>
        <source>out of sync</source>
        <translation type="vanished">未同步</translation>
    </message>
    <message>
        <source>rejected</source>
        <translation type="vanished">被拒绝</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="15"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="17"/>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="19"/>
        <source>This Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="21"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="23"/>
        <source>Syncing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="25"/>
        <source>Out of Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="27"/>
        <source>Rejected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingDir</name>
    <message>
        <source>paused</source>
        <translation type="vanished">已暂停</translation>
    </message>
    <message>
        <source>unshared</source>
        <translation type="vanished">未分享</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="180"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="183"/>
        <source>Unshared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="18"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="195"/>
        <source>Local Additions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="197"/>
        <source>Unexpected Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="20"/>
        <source>Up to Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="22"/>
        <source>Waiting to Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="205"/>
        <source>Scanning (%1 %, %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="209"/>
        <source>Scanning (%1 %)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="24"/>
        <source>Scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="26"/>
        <source>Waiting to Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="28"/>
        <source>Preparing to Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="214"/>
        <source>Syncing (%1 %)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="30"/>
        <source>Syncing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="32"/>
        <source>Cleaning Versions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="34"/>
        <source>Waiting to Clean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="36"/>
        <source>Out of Sync</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingDirStatus</name>
    <message>
        <source>unknown</source>
        <translation type="vanished">未知</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">空闲</translation>
    </message>
    <message>
        <source>scanning</source>
        <translation type="vanished">扫描中</translation>
    </message>
    <message>
        <source>waiting to scan</source>
        <translation type="vanished">等待扫描</translation>
    </message>
    <message>
        <source>waiting to sync</source>
        <translation type="vanished">等待同步</translation>
    </message>
    <message>
        <source>preparing to sync</source>
        <translation type="vanished">准备同步</translation>
    </message>
    <message>
        <source>synchronizing</source>
        <translation type="vanished">同步中</translation>
    </message>
    <message>
        <source>cleaning</source>
        <translation type="vanished">清理中</translation>
    </message>
    <message>
        <source>waiting to clean</source>
        <translation type="vanished">等待清理</translation>
    </message>
    <message>
        <source>out of sync</source>
        <translation type="vanished">未同步</translation>
    </message>
</context>
<context>
    <name>SyncthingDirType</name>
    <message>
        <source>unknown</source>
        <translation type="vanished">未知</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="45"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="47"/>
        <source>Send &amp; Receive</source>
        <translation>发送与接受</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="49"/>
        <source>Send Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="51"/>
        <source>Receive Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="53"/>
        <source>Receive Encrypted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send only</source>
        <translation type="vanished">仅发送</translation>
    </message>
    <message>
        <source>Receive only</source>
        <translation type="vanished">仅接受</translation>
    </message>
</context>
</TS>
